==> edge-login-ui-rn-0.10.15.tgz: package/lib/components/common/WarningCard.js <==
import * as React from 'react';
import { Platform, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import IonIcon from 'react-native-vector-icons/Ionicons';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
/**
 * A warning card that accepts a title, header, bullet points and a footer,
 * rendering the bullet points with the correct vertical alignment when
 * the messages overflow.
 *  .___________________________.
 *  | ⚠ Warning                 |
 *  |                           |
 *  | This is the header text   |
 *  |                           |
 *  | • This is an overflowing  |
 *  |   bulletpoint message     |
 *  | • This one's short        |
 *  |                           |
 *  | This is the footer text   |
 *  |___________________________|
 */
export function WarningCard({ title, header, points, footer, marginRem, paddingRem }) {
    const theme = useTheme();
    const margin = sidesToMargin(mapSides(fixSides(marginRem, 1), theme.rem));
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 1), theme.rem));
    const styles = getStyles(theme);
    const renderBulletpoint = (message) => {
        return (React.createElement(View, { style: styles.bulletpointRow, key: message },
            React.createElement(EdgeText, { style: styles.bulletpointText }, '\u2022 '),
            React.createElement(EdgeText, { style: styles.bulletpointText, numberOfLines: 0 }, message)));
    };
    return (React.createElement(View, { style: [styles.warning, margin, padding] },
        React.createElement(View, { style: styles.titleContainer },
            React.createElement(IonIcon, { name: Platform.OS === 'ios' ? 'ios-warning-outline' : 'md-warning-outline', style: styles.icon, color: theme.warningText, size: theme.rem(0.8) }),
            React.createElement(EdgeText, { style: styles.title }, title)),
        header != null && (React.createElement(EdgeText, { style: styles.text, numberOfLines: 0 }, header)),
        points != null && points.length > 0 && (React.createElement(View, { style: styles.bulletpoints }, points === null || points === void 0 ? void 0 : points.map(point => renderBulletpoint(point)))),
        footer != null && (React.createElement(EdgeText, { style: styles.text, numberOfLines: 0 }, footer))));
}
const getStyles = (theme) => cacheStyles((theme) => ({
    warning: {
        borderWidth: theme.cardBorder,
        borderColor: theme.warningText,
        borderRadius: theme.cardBorderRadius,
        margin: theme.rem(1),
        alignSelf: 'stretch'
    },
    titleContainer: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center'
    },
    title: {
        fontSize: theme.rem(0.75),
        marginLeft: theme.rem(0.25),
        fontFamily: theme.fontFaceBold,
        color: theme.warningText
    },
    icon: {
        marginRight: theme.rem(0.5)
    },
    text: {
        fontSize: theme.rem(0.75),
        marginTop: theme.rem(1),
        fontFamily: theme.fontFaceDefault,
        color: theme.warningText
    },
    bulletpoints: {
        marginTop: theme.rem(0.5)
    },
    bulletpointRow: {
        flexDirection: 'row'
    },
    bulletpointText: {
        marginLeft: theme.rem(0.2),
        fontSize: theme.rem(0.75),
        color: theme.warningText,
        fontFamily: theme.fontFaceDefault
    }
}))(theme);

==> edge-login-ui-rn-2.1.0.tgz: package/lib/components/common/WarningCard.js <==
import * as React from 'react';
import { Platform, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import IonIcon from 'react-native-vector-icons/Ionicons';
import { fixSides, mapSides, sidesToMargin, sidesToPadding } from '../../util/sides';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
/**
 * A warning card that accepts a title, header, bullet points and a footer,
 * rendering the bullet points with the correct vertical alignment when
 * the messages overflow.
 *  .___________________________.
 *  | ⚠ Warning                 |
 *  |                           |
 *  | This is the header text   |
 *  |                           |
 *  | • This is an overflowing  |
 *  |   bulletpoint message     |
 *  | • This one's short        |
 *  |                           |
 *  | This is the footer text   |
 *  |___________________________|
 */
export function WarningCard({ title, header, points, footer, marginRem, paddingRem }) {
    const theme = useTheme();
    const margin = sidesToMargin(mapSides(fixSides(marginRem, 1), theme.rem));
    const padding = sidesToPadding(mapSides(fixSides(paddingRem, 1), theme.rem));
    const styles = getStyles(theme);
    const renderBulletpoint = (message) => {
        return (React.createElement(View, { style: styles.bulletpointRow, key: message },
            React.createElement(EdgeText, { style: styles.bulletpointText }, '\u2022 '),
            React.createElement(EdgeText, { style: styles.bulletpointText, numberOfLines: 0 }, message)));
    };
    return (React.createElement(View, { style: [styles.warning, margin, padding] },
        React.createElement(View, { style: styles.titleContainer },
            React.createElement(IonIcon, { name: Platform.OS === 'ios' ? 'ios-warning-outline' : 'md-warning-outline', style: styles.icon, color: theme.warningText, size: theme.rem(0.8) }),
            React.createElement(EdgeText, { style: styles.title }, title)),
        header == null ? null : (React.createElement(EdgeText, { style: styles.text, numberOfLines: 0 }, header)),
        points == null || points.length === 0 ? null : (React.createElement(View, { style: styles.bulletpoints }, points === null || points === void 0 ? void 0 : points.map(point => renderBulletpoint(point)))),
        footer == null ? null : (React.createElement(EdgeText, { style: styles.text, numberOfLines: 0 }, footer))));
}
const getStyles = (theme) => cacheStyles((theme) => ({
    warning: {
        borderWidth: theme.cardBorder,
        borderColor: theme.warningText,
        borderRadius: theme.cardBorderRadius,
        margin: theme.rem(1),
        alignSelf: 'stretch'
    },
    titleContainer: {
        display: 'flex',
        flexDirection: 'row',
        alignItems: 'center'
    },
    title: {
        fontSize: theme.rem(0.75),
        marginLeft: theme.rem(0.25),
        fontFamily: theme.fontFaceBold,
        color: theme.warningText
    },
    icon: {
        marginRight: theme.rem(0.5)
    },
    text: {
        fontSize: theme.rem(0.75),
        marginTop: theme.rem(1),
        fontFamily: theme.fontFaceDefault,
        color: theme.warningText
    },
    bulletpoints: {
        marginTop: theme.rem(0.5)
    },
    bulletpointRow: {
        flexDirection: 'row'
    },
    bulletpointText: {
        marginLeft: theme.rem(0.2),
        fontSize: theme.rem(0.75),
        color: theme.warningText,
        fontFamily: theme.fontFaceDefault
    }
}))(theme);
